from cryptography.x509 import load_pem_x509_certificates, Certificate
from ._openssl import extract_certificates as _extract_certificates
from ._openssl import InvalidPassword, InvalidPKCS12File

def extract_certificates(pkcs12: bytes, password: str) -> list[Certificate]:
    return load_pem_x509_certificates(_extract_certificates(pkcs12, password))



from .pkcs12 import extract_certificates
from pathlib import Path
from argparse import ArgumentParser

if __name__ == "__main__":
    parser = ArgumentParser(prog="pined.openssl")
    parser.add_argument("pkcs12", type=Path)
    parser.add_argument("password", type=str)
    args = parser.parse_args()
    with args.pkcs12.open("rb") as f:
        certificates = extract_certificates(f.read(), args.password)
        for c in certificates:
            print(c)



from pathlib import Path
from pined.openssl.pkcs12 import InvalidPassword, InvalidPKCS12File, extract_certificates

import pytest

example = Path(__file__).parent / "assets" / "example.p12"
password = "password"

def test_success():
    with example.open("rb") as f:
        certs = extract_certificates(f.read(), password)
        assert len(certs) == 1

def test_invalid_password():
    with pytest.raises(InvalidPassword):
        with example.open("rb") as f:
            extract_certificates(f.read(), "1234")

def test_invalid_file():
    with pytest.raises(InvalidPKCS12File):
        extract_certificates(b'1234', "1234")
